@@ -6,7 +6,7 @@ use utf8;
 use warnings;
 
 # Version.
-our $VERSION = 0.16;
+our $VERSION = 0.17;
 
 # Modules.
 use Acme::CPANAuthors::Register(
@@ -23,6 +23,7 @@ use Acme::CPANAuthors::Register(
 	'KLE' => 'Petr Kletečka',
 	'KOLCON' => 'Luboš Kolouch',
 	'MAJLIS' => 'Martin Majlis',
+	'MICHALS' => 'Michal Sedlák',
 	'MILSO' => 'Milan Šorm',
 	'MJFO' => 'Michal Jurosz',
 	'PAJAS' => 'Petr Pajas',
@@ -39,6 +40,8 @@ use Acme::CPANAuthors::Register(
 	'TKR' => 'Tomáš Kraut',
 	'TRIPIE' => 'Tomáš Stýblo',
 	'VASEKD' => 'Václav Dovrtěl',
+	'YENYA' => 'Jan "Yenya" Kasprzak',
+	'ZABA' => 'Zdeněk Žabokrtský',
 	'ZEMAN' => 'Dan Zeman',
 	'ZOUL' => 'Tomáš Znamenáček',
 );
@@ -89,7 +92,7 @@ See documentation for L<Acme::CPANAuthors> for more details.
  print "Count of Czech CPAN authors: $count\n";
 
  # Output:
- # Count of Czech CPAN authors: 31
+ # Count of Czech CPAN authors: 34
 
 =head1 EXAMPLE2
 
@@ -122,27 +125,30 @@ See documentation for L<Acme::CPANAuthors> for more details.
  #     [7]  "JENDA",
  #     [8]  "JIRA",
  #     [9]  "JSPICAK",
- #     [10]  "KLE",
+ #     [10] "KLE",
  #     [11] "KOLCON",
  #     [12] "MAJLIS",
- #     [13] "MILSO",
- #     [14] "MJFO",
- #     [15] "PAJAS",
- #     [16] "PASKY",
- #     [17] "PEK",
- #     [18] "POPEL",
- #     [19] "PSME",
- #     [20] "RUR",
- #     [21] "RVASICEK",
- #     [22] "SEIDLJAN",
- #     [23] "SKIM",
- #     [24] "SMRZ",
- #     [25] "STRAKA",
- #     [26] "TKR",
- #     [27] "TRIPIE",
- #     [28] "VASEKD",
- #     [29] "ZEMAN",
- #     [30] "ZOUL"
+ #     [13] "MICHALS",
+ #     [14] "MILSO",
+ #     [15] "MJFO",
+ #     [16] "PAJAS",
+ #     [17] "PASKY",
+ #     [18] "PEK",
+ #     [19] "POPEL",
+ #     [20] "PSME",
+ #     [21] "RUR",
+ #     [22] "RVASICEK",
+ #     [23] "SEIDLJAN",
+ #     [24] "SKIM",
+ #     [25] "SMRZ",
+ #     [26] "STRAKA",
+ #     [27] "TKR",
+ #     [28] "TRIPIE",
+ #     [29] "VASEKD",
+ #     [30] "YENYA",
+ #     [31] "ZABA",
+ #     [32] "ZEMAN",
+ #     [33] "ZOUL"
  # ]
 
 =head1 DEPENDENCIES
@@ -166,6 +172,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.16
+0.17
 
 =cut
